@@ -8,7 +8,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * SCCS: @(#) tkMenu.h 1.60 97/06/20 14:43:21
+ * RCS: @(#) $Id: tkMenu.h,v 1.4 1998/09/14 18:23:14 stanton Exp $
  */
 
 #ifndef _TKMENU
@@ -50,7 +50,7 @@ typedef struct TkMenuEntry {
     char *label;		/* Main text label displayed in entry (NULL
 				 * if no label).  Malloc'ed. */
     int labelLength;		/* Number of non-NULL characters in label. */
-    Tk_State state;		/* State of button for display purposes:
+    Tk_Uid state;		/* State of button for display purposes:
 				 * normal, active, or disabled. */
     int underline;		/* Index of character to underline. */
     Pixmap bitmap;		/* Bitmap to display in menu entry, or None.
@@ -182,9 +182,6 @@ typedef struct TkMenuEntry {
   				 * Depends on platform and menu type what
   				 * kind of options are in this structure.
   				 */
-    Tk_Tile tile, activeTile, disabledTile;
-    Tk_TSOffset tsoffset;
-    GC tileGC, activeTileGC, disabledTileGC;
 } TkMenuEntry;
 
 /*
@@ -363,9 +360,6 @@ typedef struct TkMenu {
   				 * Depends on platform and menu type what
   				 * kind of options are in this structure.
   				 */
-    Tk_Tile tile, activeTile, disabledTile;
-    Tk_TSOffset tsoffset;
-    GC tileGC, activeTileGC, disabledTileGC;
 } TkMenu;
 
 /*
