@@ -12,20 +12,9 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * SCCS: @(#) tkTest.c 1.50 97/11/06 16:56:32
+ * RCS: @(#) $Id: tkTest.c,v 1.3 1998/09/14 18:23:17 stanton Exp $
  */
 
-#ifdef __cplusplus
-extern "C" {
-#endif
-
-/*
- * Allow this file to be compiled as loadable library (dll) separate
- * from the Tk shared library (or dll). We don't want all
- * dll symbols to be exported, only the Tktest_Init() function.
- */
-#undef BUILD_tk
-
 #include "tkInt.h"
 #include "tkPort.h"	
 
@@ -41,23 +30,6 @@ extern "C" {
 #include "tkUnixInt.h"
 #endif
 
-/*
- * TCL_STORAGE_CLASS is set unconditionally to DLLEXPORT because the
- * Tktest_Init declaration is in the source file itself, which is only
- * accessed when we are building a library.
- */
-
-#undef TCL_STORAGE_CLASS
-#define TCL_STORAGE_CLASS DLLEXPORT
-
-#ifdef __cplusplus
-}
-#define dummy  /* */
-#define dummy2 /* */
-#define dummy3 /* */
-#define dummy4 /* */
-#endif
-
 /*
  * The following data structure represents the master for a test
  * image:
@@ -109,7 +81,6 @@ static Tk_ImageType imageType = {
     ImageDisplay,		/* displayProc */
     ImageFree,			/* freeProc */
     ImageDelete,		/* deleteProc */
-    (Tk_ImagePostscriptProc *) NULL,/* postscriptPtr */
     (Tk_ImageType *) NULL	/* nextPtr */
 };
 
@@ -124,13 +95,20 @@ typedef struct NewApp {
     struct NewApp *nextPtr;	/* Next in list of new interpreters. */
 } NewApp;
 
-static NewApp *newAppPtr = (NewApp *) NULL;
+static NewApp *newAppPtr = NULL;
 				/* First in list of all new interpreters. */
 
+/*
+ * Declaration for the square widget's class command procedure:
+ */
+
+extern int SquareCmd _ANSI_ARGS_((ClientData clientData,
+	Tcl_Interp *interp, int argc, char *argv[]));
+
 typedef struct CBinding {
     Tcl_Interp *interp;
     char *command;
-    char *del;
+    char *delete;
 } CBinding;
 
 /*
@@ -141,7 +119,7 @@ static int		CBindingEvalProc _ANSI_ARGS_((ClientData clientData,
 			    Tcl_Interp *interp, XEvent *eventPtr,
 			    Tk_Window tkwin, KeySym keySym));
 static void		CBindingFreeProc _ANSI_ARGS_((ClientData clientData));
-EXTERN Tktest_Init _ANSI_ARGS_((Tcl_Interp *interp));
+int			Tktest_Init _ANSI_ARGS_((Tcl_Interp *interp));
 static int		ImageCmd _ANSI_ARGS_((ClientData dummy,
 			    Tcl_Interp *interp, int argc, char **argv));
 static int		TestcbindCmd _ANSI_ARGS_((ClientData dummy,
@@ -151,33 +129,32 @@ static int		TestclipboardCmd _ANSI_ARGS_((ClientData dummy,
 			    Tcl_Interp *interp, int argc, char **argv));
 #endif
 static int		TestdeleteappsCmd _ANSI_ARGS_((ClientData dummy,
-			    Tcl_Interp *interp, int argc, Tcl_Obj *CONST argv[]));
+			    Tcl_Interp *interp, int argc, char **argv));
 static int		TestmakeexistCmd _ANSI_ARGS_((ClientData dummy,
-			    Tcl_Interp *interp, int argc, Tcl_Obj *CONST argv[]));
+			    Tcl_Interp *interp, int argc, char **argv));
 static int		TestmenubarCmd _ANSI_ARGS_((ClientData dummy,
-			    Tcl_Interp *interp, int argc, Tcl_Obj *CONST argv[]));
+			    Tcl_Interp *interp, int argc, char **argv));
 #if defined(__WIN32__) || defined(MAC_TCL)
 static int		TestmetricsCmd _ANSI_ARGS_((ClientData dummy,
-			    Tcl_Interp *interp, int argc, Tcl_Obj *CONST argv[]));
+			    Tcl_Interp *interp, int argc, char **argv));
 #endif
 static int		TestsendCmd _ANSI_ARGS_((ClientData dummy,
-			    Tcl_Interp *interp, int argc, Tcl_Obj *CONST argv[]));
+			    Tcl_Interp *interp, int argc, char **argv));
 static int		TestpropCmd _ANSI_ARGS_((ClientData dummy,
-			    Tcl_Interp *interp, int argc, Tcl_Obj *CONST argv[]));
+			    Tcl_Interp *interp, int argc, char **argv));
 #if !(defined(__WIN32__) || defined(MAC_TCL))
 static int		TestwrapperCmd _ANSI_ARGS_((ClientData dummy,
-			    Tcl_Interp *interp, int argc, Tcl_Obj *CONST argv[]));
+			    Tcl_Interp *interp, int argc, char **argv));
 #endif
 
 /*
  * External (platform specific) initialization routine:
  */
 
-#ifndef MAC_TCL
-#define TkplatformtestInit(x) TCL_OK
-#else
 EXTERN int		TkplatformtestInit _ANSI_ARGS_((
 			    Tcl_Interp *interp));
+#ifndef MAC_TCL
+#define TkplatformtestInit(x) TCL_OK
 #endif
 
 /*
@@ -199,13 +176,8 @@ EXTERN int		TkplatformtestInit _ANSI_ARGS_((
  */
 
 int
-#ifdef _USING_PROTOTYPES_
-Tktest_Init (
-    Tcl_Interp *interp)		/* Interpreter for application. */
-#else
 Tktest_Init(interp)
     Tcl_Interp *interp;		/* Interpreter for application. */
-#endif
 {
     static int initialized = 0;
 
@@ -213,37 +185,36 @@ Tktest_Init(interp)
      * Create additional commands for testing Tk.
      */
 
-    if (Tcl_PkgRequire(interp, "Tk", TK_VERSION, 1) == NULL) {
-	return TCL_ERROR;
-    }
     if (Tcl_PkgProvide(interp, "Tktest", TK_VERSION) == TCL_ERROR) {
         return TCL_ERROR;
     }
 
+    Tcl_CreateCommand(interp, "square", SquareCmd,
+	    (ClientData) Tk_MainWindow(interp), (Tcl_CmdDeleteProc *) NULL);
 #ifdef __WIN32__
     Tcl_CreateCommand(interp, "testclipboard", TestclipboardCmd,
 	    (ClientData) Tk_MainWindow(interp), (Tcl_CmdDeleteProc *) NULL);
 #endif
     Tcl_CreateCommand(interp, "testcbind", TestcbindCmd,
 	    (ClientData) Tk_MainWindow(interp), (Tcl_CmdDeleteProc *) NULL);
-    Tcl_CreateObjCommand(interp, "testdeleteapps", TestdeleteappsCmd,
+    Tcl_CreateCommand(interp, "testdeleteapps", TestdeleteappsCmd,
 	    (ClientData) Tk_MainWindow(interp), (Tcl_CmdDeleteProc *) NULL);
     Tcl_CreateCommand(interp, "testembed", TkpTestembedCmd,
 	    (ClientData) Tk_MainWindow(interp), (Tcl_CmdDeleteProc *) NULL);
-    Tcl_CreateObjCommand(interp, "testmakeexist", TestmakeexistCmd,
+    Tcl_CreateCommand(interp, "testmakeexist", TestmakeexistCmd,
 	    (ClientData) Tk_MainWindow(interp), (Tcl_CmdDeleteProc *) NULL);
-    Tcl_CreateObjCommand(interp, "testmenubar", TestmenubarCmd,
+    Tcl_CreateCommand(interp, "testmenubar", TestmenubarCmd,
 	    (ClientData) Tk_MainWindow(interp), (Tcl_CmdDeleteProc *) NULL);
 #if defined(__WIN32__) || defined(MAC_TCL)
-    Tcl_CreateObjCommand(interp, "testmetrics", TestmetricsCmd,
+    Tcl_CreateCommand(interp, "testmetrics", TestmetricsCmd,
 	    (ClientData) Tk_MainWindow(interp), (Tcl_CmdDeleteProc *) NULL);
 #endif
-    Tcl_CreateObjCommand(interp, "testprop", TestpropCmd,
+    Tcl_CreateCommand(interp, "testprop", TestpropCmd,
 	    (ClientData) Tk_MainWindow(interp), (Tcl_CmdDeleteProc *) NULL);
-    Tcl_CreateObjCommand(interp, "testsend", TestsendCmd,
+    Tcl_CreateCommand(interp, "testsend", TestsendCmd,
 	    (ClientData) Tk_MainWindow(interp), (Tcl_CmdDeleteProc *) NULL);
 #if !(defined(__WIN32__) || defined(MAC_TCL))
-    Tcl_CreateObjCommand(interp, "testwrapper", TestwrapperCmd,
+    Tcl_CreateCommand(interp, "testwrapper", TestwrapperCmd,
 	    (ClientData) Tk_MainWindow(interp), (Tcl_CmdDeleteProc *) NULL);
 #endif
 
@@ -282,19 +253,11 @@ Tktest_Init(interp)
 
 #ifdef __WIN32__
 static int
-#ifdef _USING_PROTOTYPES_
-TestclipboardCmd (
-    ClientData clientData,		/* Main window for application. */
-    Tcl_Interp *interp,			/* Current interpreter. */
-    int argc,				/* Number of arguments. */
-    char **argv)			/* Argument strings. */
-#else
 TestclipboardCmd(clientData, interp, argc, argv)
     ClientData clientData;		/* Main window for application. */
     Tcl_Interp *interp;			/* Current interpreter. */
     int argc;				/* Number of arguments. */
     char **argv;			/* Argument strings. */
-#endif
 {
     TkWindow *winPtr = (TkWindow *) clientData;
     HGLOBAL handle;
@@ -331,19 +294,11 @@ TestclipboardCmd(clientData, interp, argc, argv)
  */
 
 static int
-#ifdef _USING_PROTOTYPES_
-TestcbindCmd (
-    ClientData clientData,		/* Main window for application. */
-    Tcl_Interp *interp,			/* Current interpreter. */
-    int argc,				/* Number of arguments. */
-    char **argv)			/* Argument strings. */
-#else
 TestcbindCmd(clientData, interp, argc, argv)
     ClientData clientData;		/* Main window for application. */
     Tcl_Interp *interp;			/* Current interpreter. */
     int argc;				/* Number of arguments. */
     char **argv;			/* Argument strings. */
-#endif
 {
     TkWindow *winPtr;
     Tk_Window tkwin;
@@ -380,9 +335,9 @@ TestcbindCmd(clientData, interp, argc, argv)
     cbindPtr->command =
 	    strcpy((char *) ckalloc(strlen(argv[3]) + 1), argv[3]);
     if (argc == 4) {
-	cbindPtr->del = NULL;
+	cbindPtr->delete = NULL;
     } else {
-	cbindPtr->del =
+	cbindPtr->delete =
 		strcpy((char *) ckalloc(strlen(argv[4]) + 1), argv[4]);
     }
 
@@ -390,8 +345,8 @@ TestcbindCmd(clientData, interp, argc, argv)
 	    object, argv[2], CBindingEvalProc, CBindingFreeProc,
 	    (ClientData) cbindPtr) == 0) {
 	ckfree((char *) cbindPtr->command);
-	if (cbindPtr->del != NULL) {
-	    ckfree((char *) cbindPtr->del);
+	if (cbindPtr->delete != NULL) {
+	    ckfree((char *) cbindPtr->delete);
 	}
 	ckfree((char *) cbindPtr);
 	return TCL_ERROR;
@@ -400,21 +355,12 @@ TestcbindCmd(clientData, interp, argc, argv)
 }
 
 static int
-#ifdef _USING_PROTOTYPES_
-CBindingEvalProc (
-    ClientData clientData,
-    Tcl_Interp *interp,
-    XEvent *dummy,
-    Tk_Window dummy2,
-    KeySym dummy3)
-#else
-CBindingEvalProc(clientData, interp, dummy, dummy2, dummy3)
+CBindingEvalProc(clientData, interp, eventPtr, tkwin, keySym)
     ClientData clientData;
     Tcl_Interp *interp;
-    XEvent *dummy;
-    Tk_Window dummy2;
-    KeySym dummy3;
-#endif
+    XEvent *eventPtr;
+    Tk_Window tkwin;
+    KeySym keySym;
 {
     CBinding *cbindPtr;
 
@@ -424,19 +370,14 @@ CBindingEvalProc(clientData, interp, dummy, dummy2, dummy3)
 }
 
 static void
-#ifdef _USING_PROTOTYPES_
-CBindingFreeProc (
-    ClientData clientData)
-#else
 CBindingFreeProc(clientData)
     ClientData clientData;
-#endif
 {
     CBinding *cbindPtr = (CBinding *) clientData;
     
-    if (cbindPtr->del != NULL) {
-	Tcl_GlobalEval(cbindPtr->interp, cbindPtr->del);
-	ckfree((char *) cbindPtr->del);
+    if (cbindPtr->delete != NULL) {
+	Tcl_GlobalEval(cbindPtr->interp, cbindPtr->delete);
+	ckfree((char *) cbindPtr->delete);
     }
     ckfree((char *) cbindPtr->command);
     ckfree((char *) cbindPtr);
@@ -462,19 +403,11 @@ CBindingFreeProc(clientData)
 
 	/* ARGSUSED */
 static int
-#ifdef _USING_PROTOTYPES_
-TestdeleteappsCmd (
-    ClientData dummy,			/* Main window for application. */
-    Tcl_Interp *dummy2,			/* Current interpreter. */
-    int dummy3,				/* Number of arguments. */
-    Tcl_Obj *CONST dummy4[])		/* Argument strings. */
-#else
-TestdeleteappsCmd(dummy, dummy2, dummy3, dummy4)
-    ClientData dummy;			/* Main window for application. */
-    Tcl_Interp *dummy2;			/* Current interpreter. */
-    int dummy3;				/* Number of arguments. */
-    Tcl_Obj *CONST *dummy4[];		/* Argument strings. */
-#endif
+TestdeleteappsCmd(clientData, interp, argc, argv)
+    ClientData clientData;		/* Main window for application. */
+    Tcl_Interp *interp;			/* Current interpreter. */
+    int argc;				/* Number of arguments. */
+    char **argv;			/* Argument strings. */
 {
     NewApp *nextPtr;
 
@@ -631,17 +564,10 @@ ImageCmd(clientData, interp, argc, argv)
  */
 
 static ClientData
-#ifdef _USING_PROTOTYPES_
-ImageGet (
-    Tk_Window tkwin,		/* Token for window in which image will
-				 * be used. */
-    ClientData clientData)	/* Pointer to TImageMaster for image. */
-#else
 ImageGet(tkwin, clientData)
     Tk_Window tkwin;		/* Token for window in which image will
 				 * be used. */
     ClientData clientData;	/* Pointer to TImageMaster for image. */
-#endif
 {
     TImageMaster *timPtr = (TImageMaster *) clientData;
     TImageInstance *instPtr;
@@ -679,17 +605,6 @@ ImageGet(tkwin, clientData)
  */
 
 static void
-#ifdef _USING_PROTOTYPES_
-ImageDisplay (
-    ClientData clientData,	/* Pointer to TImageInstance for image. */
-    Display *display,		/* Display to use for drawing. */
-    Drawable drawable,		/* Where to redraw image. */
-    int imageX, int imageY,	/* Origin of area to redraw, relative to
-				 * origin of image. */
-    int width, int height,	/* Dimensions of area to redraw. */
-    int drawableX,		/* Coordinates in drawable corresponding to */
-    int drawableY)		/* imageX and imageY. */
-#else
 ImageDisplay(clientData, display, drawable, imageX, imageY, width, height,
 	drawableX, drawableY)
     ClientData clientData;	/* Pointer to TImageInstance for image. */
@@ -700,7 +615,6 @@ ImageDisplay(clientData, display, drawable, imageX, imageY, width, height,
     int width, height;		/* Dimensions of area to redraw. */
     int drawableX, drawableY;	/* Coordinates in drawable corresponding to
 				 * imageX and imageY. */
-#endif
 {
     TImageInstance *instPtr = (TImageInstance *) clientData;
     char buffer[200];
@@ -743,15 +657,9 @@ ImageDisplay(clientData, display, drawable, imageX, imageY, width, height,
  */
 
 static void
-#ifdef _USING_PROTOTYPES_
-ImageFree (
-    ClientData clientData,	/* Pointer to TImageInstance for instance. */
-    Display *display)		/* Display where image was to be drawn. */
-#else
 ImageFree(clientData, display)
     ClientData clientData;	/* Pointer to TImageInstance for instance. */
     Display *display;		/* Display where image was to be drawn. */
-#endif
 {
     TImageInstance *instPtr = (TImageInstance *) clientData;
     char buffer[200];
@@ -782,17 +690,10 @@ ImageFree(clientData, display)
  */
 
 static void
-#ifdef _USING_PROTOTYPES_
-ImageDelete (
-    ClientData clientData)	/* Pointer to TImageMaster for image.  When
-				 * this procedure is called, no more
-				 * instances exist. */
-#else
 ImageDelete(clientData)
     ClientData clientData;	/* Pointer to TImageMaster for image.  When
 				 * this procedure is called, no more
 				 * instances exist. */
-#endif
 {
     TImageMaster *timPtr = (TImageMaster *) clientData;
     char buffer[100];
@@ -827,27 +728,18 @@ ImageDelete(clientData)
 
 	/* ARGSUSED */
 static int
-#ifdef _USING_PROTOTYPES_
-TestmakeexistCmd (
-    ClientData clientData,		/* Main window for application. */
-    Tcl_Interp *interp,			/* Current interpreter. */
-    int argc,				/* Number of arguments. */
-    Tcl_Obj *CONST argv[])		/* Argument objects. */
-#else
 TestmakeexistCmd(clientData, interp, argc, argv)
     ClientData clientData;		/* Main window for application. */
     Tcl_Interp *interp;			/* Current interpreter. */
     int argc;				/* Number of arguments. */
-    Tcl_Obj *CONST argv[];		/* Argument strings. */
-#endif
+    char **argv;			/* Argument strings. */
 {
     Tk_Window mainwin = (Tk_Window) clientData;
     int i;
     Tk_Window tkwin;
 
     for (i = 1; i < argc; i++) {
-	tkwin = Tk_NameToWindow(interp, Tcl_GetStringFromObj(argv[i], NULL),
-		mainwin);
+	tkwin = Tk_NameToWindow(interp, argv[i], mainwin);
 	if (tkwin == NULL) {
 	    return TCL_ERROR;
 	}
@@ -877,51 +769,36 @@ TestmakeexistCmd(clientData, interp, argc, argv)
 
 	/* ARGSUSED */
 static int
-#ifdef _USING_PROTOTYPES_
-TestmenubarCmd (
-    ClientData clientData,		/* Main window for application. */
-    Tcl_Interp *interp,			/* Current interpreter. */
-    int argc,				/* Number of arguments. */
-    Tcl_Obj *CONST argv[])		/* Argument objects. */
-#else
 TestmenubarCmd(clientData, interp, argc, argv)
     ClientData clientData;		/* Main window for application. */
     Tcl_Interp *interp;			/* Current interpreter. */
     int argc;				/* Number of arguments. */
-    Tcl_Obj *CONST argv[];		/* Argument strings. */
-#endif
+    char **argv;			/* Argument strings. */
 {
 #ifdef __UNIX__
     Tk_Window mainwin = (Tk_Window) clientData;
     Tk_Window tkwin, menubar;
-    int index;
-    static char *optionStrings[] = {
-      "window",       NULL
-    };
 
     if (argc < 2) {
-	Tcl_WrongNumArgs(interp, 1, argv, "option ?arg ...?");
+	Tcl_AppendResult(interp, "wrong # args;  must be \"", argv[0],
+		" option ?arg ...?\"", (char *) NULL);
 	return TCL_ERROR;
     }
-    if (Tcl_GetIndexFromObj(interp, argv[1], optionStrings, "option", 0,
-	    &index) != TCL_OK) {
-	return TCL_ERROR;
-    }
-    if (index == 0) {
+
+    if (strcmp(argv[1], "window") == 0) {
 	if (argc != 4) {
-	    Tcl_WrongNumArgs(interp, 2, argv, "window toplevel menubar");
+	    Tcl_AppendResult(interp, "wrong # args;  must be \"", argv[0],
+		    "window toplevel menubar\"", (char *) NULL);
 	    return TCL_ERROR;
 	}
-	tkwin = Tk_NameToWindow(interp, Tcl_GetStringFromObj(argv[2], NULL),
-		mainwin);
+	tkwin = Tk_NameToWindow(interp, argv[2], mainwin);
 	if (tkwin == NULL) {
 	    return TCL_ERROR;
 	}
-	if (Tcl_GetStringFromObj(argv[3], NULL)[0] == 0) {
+	if (argv[3][0] == 0) {
 	    TkUnixSetMenubar(tkwin, NULL);
 	} else {
-	    menubar = Tk_NameToWindow(interp,
-		    Tcl_GetStringFromObj(argv[3], NULL), mainwin);
+	    menubar = Tk_NameToWindow(interp, argv[3], mainwin);
 	    if (menubar == NULL) {
 		return TCL_ERROR;
 	    }
@@ -959,70 +836,53 @@ TestmenubarCmd(clientData, interp, argc, argv)
 
 #ifdef __WIN32__
 static int
-#ifdef _USING_PROTOTYPES_
-TestmetricsCmd (
-    ClientData clientData,		/* Main window for application. */
-    Tcl_Interp *interp,			/* Current interpreter. */
-    int argc,				/* Number of arguments. */
-    Tcl_Obj *CONST argv[])		/* Argument objects. */
-#else
-TestmetricsCmd(clientData, interp, argc, argv)
-    ClientData clientData;		/* Main window for application. */
-    Tcl_Interp *interp;			/* Current interpreter. */
-    int argc;				/* Number of arguments. */
-    Tcl_Obj *CONST argv[];		/* Argument strings. */
-#endif
-{
-    int index;
-    static char *optionStrings[] = {
-	"cyvscroll",	"cxhscroll",	NULL
-    };
-
-    if (argc < 2) {
-	Tcl_WrongNumArgs(interp, 1, argv, " option ?arg ...?");
-	return TCL_ERROR;
-    }
-    if (Tcl_GetIndexFromObj(interp, argv[1], optionStrings, "option", 0,
-	    &index) != TCL_OK) {
-	return TCL_ERROR;
-    }
-    Tcl_SetObjResult(interp, Tcl_NewIntObj(
-	    GetSystemMetrics(index?SM_CXHSCROLL:SM_CYVSCROLL)));
-    return TCL_OK;
-}
-#endif
-
-#ifdef MAC_TCL
-static int
-#ifdef _USING_PROTOTYPES_
-TestmetricsCmd (
-    ClientData clientData,		/* Main window for application. */
-    Tcl_Interp *interp,			/* Current interpreter. */
-    int argc,				/* Number of arguments. */
-    char **argv)			/* Argument strings. */
-#else
 TestmetricsCmd(clientData, interp, argc, argv)
     ClientData clientData;		/* Main window for application. */
     Tcl_Interp *interp;			/* Current interpreter. */
     int argc;				/* Number of arguments. */
     char **argv;			/* Argument strings. */
+{
+    char buf[200];
+
+    if (argc < 2) {
+	Tcl_AppendResult(interp, "wrong # args;  must be \"", argv[0],
+		" option ?arg ...?\"", (char *) NULL);
+	return TCL_ERROR;
+    }
+
+    if (strcmp(argv[1], "cyvscroll") == 0) {
+	sprintf(buf, "%d", GetSystemMetrics(SM_CYVSCROLL));
+	Tcl_AppendResult(interp, buf, (char *) NULL);
+    } else  if (strcmp(argv[1], "cxhscroll") == 0) {
+	sprintf(buf, "%d", GetSystemMetrics(SM_CXHSCROLL));
+	Tcl_AppendResult(interp, buf, (char *) NULL);
+    } else {
+	Tcl_AppendResult(interp, "bad option \"", argv[1],
+		"\": must be cxhscroll or cyvscroll", (char *) NULL);
+	return TCL_ERROR;
+    }
+    return TCL_OK;
+}
 #endif
+#ifdef MAC_TCL
+static int
+TestmetricsCmd(clientData, interp, argc, argv)
+    ClientData clientData;		/* Main window for application. */
+    Tcl_Interp *interp;			/* Current interpreter. */
+    int argc;				/* Number of arguments. */
+    char **argv;			/* Argument strings. */
 {
     Tk_Window tkwin = (Tk_Window) clientData;
     TkWindow *winPtr;
     char buf[200];
 
-    int index;
-    static char *optionStrings[] = {
-	"cyvscroll",	"cxhscroll",	NULL
-    };
-
     if (argc != 3) {
-	Tcl_WrongNumArgs(interp, 1, argv, " option window");
+	Tcl_AppendResult(interp, "wrong # args;  must be \"", argv[0],
+		" option window\"", (char *) NULL);
 	return TCL_ERROR;
     }
 
-    winPtr = (TkWindow *) Tk_NameToWindow(interp, Tcl_GetStringFormObj(argv[2], NULL), tkwin);
+    winPtr = (TkWindow *) Tk_NameToWindow(interp, argv[2], tkwin);
     if (winPtr == NULL) {
 	return TCL_ERROR;
     }
@@ -1038,8 +898,6 @@ TestmetricsCmd(clientData, interp, argc, argv)
 		"\": must be cxhscroll or cyvscroll", (char *) NULL);
 	return TCL_ERROR;
     }
-    Tcl_SetObjResult(Tcl_NewIntObject(
-	    GetSystemMetrics(((TkScrollbar *) winPtr->instanceData)->width))));
     return TCL_OK;
 }
 #endif
@@ -1063,19 +921,11 @@ TestmetricsCmd(clientData, interp, argc, argv)
 
 	/* ARGSUSED */
 static int
-#ifdef _USING_PROTOTYPES_
-TestpropCmd (
-    ClientData clientData,		/* Main window for application. */
-    Tcl_Interp *interp,			/* Current interpreter. */
-    int argc,				/* Number of arguments. */
-    Tcl_Obj *CONST argv[])		/* Argument objects. */
-#else
 TestpropCmd(clientData, interp, argc, argv)
     ClientData clientData;		/* Main window for application. */
     Tcl_Interp *interp;			/* Current interpreter. */
     int argc;				/* Number of arguments. */
-    Tcl_Obj *CONST argv[];		/* Argument objects. */
-#endif
+    char **argv;			/* Argument strings. */
 {
     Tk_Window mainwin = (Tk_Window) clientData;
     int result, actualFormat;
@@ -1086,12 +936,13 @@ TestpropCmd(clientData, interp, argc, argv)
     char buffer[30];
 
     if (argc != 3) {
-	Tcl_WrongNumArgs(interp, 1, argv, "window property");
+	Tcl_AppendResult(interp, "wrong # args;  must be \"", argv[0],
+		" window property\"", (char *) NULL);
 	return TCL_ERROR;
     }
 
-    w = strtoul(Tcl_GetStringFromObj(argv[1], NULL), &end, 0);
-    propName = Tk_InternAtom(mainwin, Tcl_GetStringFromObj(argv[2], NULL));
+    w = strtoul(argv[1], &end, 0);
+    propName = Tk_InternAtom(mainwin, argv[2]);
     property = NULL;
     result = XGetWindowProperty(Tk_Display(mainwin),
 	    w, propName, 0, 100000, False, AnyPropertyType,
@@ -1148,69 +999,47 @@ TestpropCmd(clientData, interp, argc, argv)
 
 	/* ARGSUSED */
 static int
-#ifdef _USING_PROTOTYPES_
-TestsendCmd (
-    ClientData clientData,		/* Main window for application. */
-    Tcl_Interp *interp,			/* Current interpreter. */
-    int argc,				/* Number of arguments. */
-    Tcl_Obj *CONST argv[])		/* Argument objects. */
-#else
 TestsendCmd(clientData, interp, argc, argv)
     ClientData clientData;		/* Main window for application. */
     Tcl_Interp *interp;			/* Current interpreter. */
     int argc;				/* Number of arguments. */
-    Tcl_Obj *CONST argv[];		/* Argument objects. */
-#endif
+    char **argv;			/* Argument strings. */
 {
     TkWindow *winPtr = (TkWindow *) clientData;
-    int index;
-    static char *optionStrings[] = {
-	"bogus",	"prop",		"serial",	NULL
-    };
-    enum options {
-	TKTEST_BOGUS,	TKTEST_PROP,	TKTEST_SERIAL
-    };
 
     if (argc < 2) {
-	Tcl_WrongNumArgs(interp, 1, argv, "option ?arg ...?");
-	return TCL_ERROR;
-    }
-    if (Tcl_GetIndexFromObj(interp, argv[1], optionStrings, "option", 0,
-	    &index) != TCL_OK) {
+	Tcl_AppendResult(interp, "wrong # args;  must be \"", argv[0],
+		" option ?arg ...?\"", (char *) NULL);
 	return TCL_ERROR;
     }
 
 #if !(defined(__WIN32__) || defined(MAC_TCL))
-    switch ((enum options) index) {
-      case TKTEST_BOGUS: {
+    if (strcmp(argv[1], "bogus") == 0) {
 	XChangeProperty(winPtr->dispPtr->display,
 		RootWindow(winPtr->dispPtr->display, 0),
 		winPtr->dispPtr->registryProperty, XA_INTEGER, 32,
 		PropModeReplace,
 		(unsigned char *) "This is bogus information", 6);
-	break;
-      }
-      case TKTEST_PROP: {
+    } else if (strcmp(argv[1], "prop") == 0) {
 	int result, actualFormat;
 	unsigned long length, bytesAfter;
 	Atom actualType, propName;
-	char *property, *p, *end, *arg;
+	char *property, *p, *end;
 	Window w;
 
 	if ((argc != 4) && (argc != 5)) {
-	    Tcl_WrongNumArgs(interp, 1, argv,
-		    "prop window name ?value ?");
+	    Tcl_AppendResult(interp, "wrong # args;  must be \"", argv[0],
+		    " prop window name ?value ?\"", (char *) NULL);
 	    return TCL_ERROR;
 	}
-	arg = Tcl_GetStringFromObj(argv[2], NULL);
-	if (strcmp(arg, "root") == 0) {
+	if (strcmp(argv[2], "root") == 0) {
 	    w = RootWindow(winPtr->dispPtr->display, 0);
-	} else if (strcmp(arg, "comm") == 0) {
+	} else if (strcmp(argv[2], "comm") == 0) {
 	    w = Tk_WindowId(winPtr->dispPtr->commTkwin);
 	} else {
-	    w = strtoul(arg, &end, 0);
+	    w = strtoul(argv[2], &end, 0);
 	}
-	propName = Tk_InternAtom((Tk_Window) winPtr, Tcl_GetStringFromObj(argv[3], NULL));
+	propName = Tk_InternAtom((Tk_Window) winPtr, argv[3]);
 	if (argc == 4) {
 	    property = NULL;
 	    result = XGetWindowProperty(winPtr->dispPtr->display,
@@ -1230,25 +1059,25 @@ TestsendCmd(clientData, interp, argc, argv)
 		XFree(property);
 	    }
 	} else {
-	    arg = Tcl_GetStringFromObj(argv[4], NULL);
-	    if (arg[0] == 0) {
+	    if (argv[4][0] == 0) {
 		XDeleteProperty(winPtr->dispPtr->display, w, propName);
 	    } else {
-		for (p = arg; *p != 0; p++) {
+		for (p = argv[4]; *p != 0; p++) {
 		    if (*p == '\n') {
 			*p = 0;
 		    }
 		}
 		XChangeProperty(winPtr->dispPtr->display,
 			w, propName, XA_STRING, 8, PropModeReplace,
-			(unsigned char *) arg, p-arg);
+			(unsigned char *) argv[4], p-argv[4]);
 	    }
 	}
-	break;
-      }
-      case TKTEST_SERIAL: {
-	Tcl_SetObjResult(interp, Tcl_NewIntObj(tkSendSerial+1));
-      }
+    } else if (strcmp(argv[1], "serial") == 0) {
+	sprintf(interp->result, "%d", tkSendSerial+1);
+    } else {
+	Tcl_AppendResult(interp, "bad option \"", argv[1],
+		"\": must be bogus, prop, or serial", (char *) NULL);
+	return TCL_ERROR;
     }
 #endif
     return TCL_OK;
@@ -1275,30 +1104,23 @@ TestsendCmd(clientData, interp, argc, argv)
 
 	/* ARGSUSED */
 static int
-#ifdef _USING_PROTOTYPES_
-TestwrapperCmd (
-    ClientData clientData,		/* Main window for application. */
-    Tcl_Interp *interp,			/* Current interpreter. */
-    int argc,				/* Number of arguments. */
-    Tcl_Obj *CONST argv[])		/* Argument objects. */
-#else
 TestwrapperCmd(clientData, interp, argc, argv)
     ClientData clientData;		/* Main window for application. */
     Tcl_Interp *interp;			/* Current interpreter. */
     int argc;				/* Number of arguments. */
-    Tcl_Obj *CONST argv[];		/* Argument strings. */
-#endif
+    char **argv;			/* Argument strings. */
 {
     TkWindow *winPtr, *wrapperPtr;
     Tk_Window tkwin;
 
     if (argc != 2) {
-	Tcl_WrongNumArgs(interp, 1, argv, "window");
+	Tcl_AppendResult(interp, "wrong # args;  must be \"", argv[0],
+		" window\"", (char *) NULL);
 	return TCL_ERROR;
     }
     
     tkwin = (Tk_Window) clientData;
-    winPtr = (TkWindow *) Tk_NameToWindow(interp, Tcl_GetStringFromObj(argv[1], NULL), tkwin);
+    winPtr = (TkWindow *) Tk_NameToWindow(interp, argv[1], tkwin);
     if (winPtr == NULL) {
 	return TCL_ERROR;
     }
